@@ -75,6 +75,7 @@ void move_source_item_remove(void *data, calldata_t *call_data)
 void move_source_scene_remove(void *data, calldata_t *call_data)
 {
 	struct move_source_info *move_source = data;
+	move_source->scene_item = NULL;
 	obs_source_t *source = (obs_source_t *)calldata_ptr(call_data, "source");
 
 	signal_handler_t *sh = obs_source_get_signal_handler(source);
@@ -295,8 +296,20 @@ void move_source_start(struct move_source_info *move_source)
 	if (!move_source->move_filter.reverse) {
 		move_source->rot_from = obs_sceneitem_get_rot(move_source->scene_item);
 		obs_sceneitem_get_pos(move_source->scene_item, &move_source->pos_from);
+		if (isinf(move_source->pos_from.x) || isnan(move_source->pos_from.x))
+			move_source->pos_from.x = 0.0f;
+		if (isinf(move_source->pos_from.y) || isnan(move_source->pos_from.y))
+			move_source->pos_from.y = 0.0f;
 		obs_sceneitem_get_scale(move_source->scene_item, &move_source->scale_from);
+		if (isinf(move_source->scale_from.x) || isnan(move_source->scale_from.x))
+			move_source->scale_from.x = 0.0f;
+		if (isinf(move_source->scale_from.y) || isnan(move_source->scale_from.y))
+			move_source->scale_from.y = 0.0f;
 		obs_sceneitem_get_bounds(move_source->scene_item, &move_source->bounds_from);
+		if (isinf(move_source->bounds_from.x) || isnan(move_source->bounds_from.x))
+			move_source->bounds_from.x = 0.0f;
+		if (isinf(move_source->bounds_from.y) || isnan(move_source->bounds_from.y))
+			move_source->bounds_from.y = 0.0f;
 		obs_sceneitem_get_crop(move_source->scene_item, &move_source->crop_from);
 		obs_source_t *scene_source = obs_scene_get_source(obs_sceneitem_get_scene(move_source->scene_item));
 		move_source->canvas_width = obs_source_get_width(scene_source);
@@ -620,6 +633,8 @@ static void *move_source_create(obs_data_t *settings, obs_source_t *source)
 	return move_source;
 }
 
+extern bool move_exit;
+
 static void move_source_destroy(void *data)
 {
 	struct move_source_info *move_source = data;
@@ -637,7 +652,7 @@ static void move_source_destroy(void *data)
 	if (move_source->scene_item) {
 		source = obs_source_get_ref(obs_sceneitem_get_source(move_source->scene_item));
 	}
-	if (!source && move_source->source_name && strlen(move_source->source_name)) {
+	if (!source && move_source->source_name && strlen(move_source->source_name) && !move_exit) {
 		source = obs_get_source_by_name(move_source->source_name);
 	}
 	if (source) {
